SystemOrganization addCategory: 'AbstractApplicationObjects'!

Exception subclass: #AbstractApplicationException
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AbstractApplicationObjects'!

AbstractApplicationException subclass: #AppObjectAlreadyInCacheException
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AbstractApplicationObjects'!

AbstractApplicationException subclass: #AppObjectNotInCacheException
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AbstractApplicationObjects'!

AbstractApplicationException subclass: #NoApplicationException
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AbstractApplicationObjects'!

AbstractApplicationException subclass: #NoAppNameException
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AbstractApplicationObjects'!

Object subclass: #AbstractApplicationObject
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AbstractApplicationObjects'!

AbstractApplicationObject subclass: #AbstractApplication
	instanceVariableNames: 'applicationName'
	classVariableNames: 'Cache'
	poolDictionaries: ''
	category: 'AbstractApplicationObjects'!

!AbstractApplication class methodsFor: 'other' stamp: 'BrunoBB 02/08/2016 13:38'!
applicationNamed: aString
	"Answer a OrbeonApplication or BpmApplication named <aString> if none answer <nil>"

	^self applicationNamed: aString ifNone: [nil]! !

!AbstractApplication class methodsFor: 'other' stamp: 'BrunoBB 02/08/2016 13:53'!
applicationNamed: aString ifNone: aBlock
	"Answer an OrbeonApplication or BpmApplication named <aString> if none evaluates the zero block argument <aBlock>"

	^self cache detect: [:each | each applicationName = aString] ifNone: aBlock! !

!AbstractApplication class methodsFor: 'other' stamp: 'BrunoBB 02/08/2016 13:53'!
cache

	Cache ifNil: [self initializeCache].

	^Cache! !

!AbstractApplication class methodsFor: 'other' stamp: 'BrunoBB 02/08/2016 13:53'!
hasApplicationNamed: aString
	"Answer whether or not the cache of the receiver has an instance named <app> as a string <aString>"

	^self cache anySatisfy: [:each | each applicationName = aString]! !

!AbstractApplication class methodsFor: 'other' stamp: 'BrunoBB 02/08/2016 14:33'!
initializeCache

	Cache := Dictionary new.

	^Cache! !

!AbstractApplication class methodsFor: 'other' stamp: 'BrunoBB 02/08/2016 13:23'!
newNamed: aString

	^super new initialize
		applicationName: aString;
		yourself! !

!AbstractApplication methodsFor: 'other' stamp: 'BrunoBB 02/08/2016 14:53'!
addToCache
	"Add the receiver to the global cache that store instances of <BpmApplication> and <OrbeonApplication>.
	The receiver must have a name and the name can not be an empty <String>"

	applicationName ifNil: [^self throwExceptionNoApplicationName].
	applicationName isEmpty ifTrue: [^self throwExceptionNoApplicationName].

	(self cache includesKey: applicationName) ifTrue: [^self throwExceptionAlreadyInCache].

	^self cache at: applicationName put: self! !

!AbstractApplication methodsFor: 'Accessing' stamp: 'BrunoBB 02/08/2016 12:40'!
applicationName
	^applicationName! !

!AbstractApplication methodsFor: 'Updating' stamp: 'BrunoBB 02/08/2016 12:40'!
applicationName: newValue
	applicationName := newValue! !

!AbstractApplication methodsFor: 'other' stamp: 'BrunoBB 02/04/2016 10:08'!
cache

	^self class cache! !

!AbstractApplication methodsFor: 'other' stamp: 'BrunoBB 12/27/2015 12:16'!
removeFromCache

	applicationName ifNil: [^self throwExceptionNoApplicationName].
	applicationName isEmpty ifTrue: [^self throwExceptionNoApplicationName].

	(self cache includesKey: applicationName) ifFalse: [^self throwExceptionNotInCache].

	^self cache removeKey: applicationName! !

!AbstractApplication methodsFor: 'other' stamp: 'BrunoBB 12/27/2015 12:15'!
throwExceptionAlreadyInCache

	^AppObjectAlreadyInCacheException signal: 'The object is already in the global cache'! !

!AbstractApplication methodsFor: 'other' stamp: 'BrunoBB 12/27/2015 12:13'!
throwExceptionNoApplicationName

	^NoAppNameException signal: 'The application must have an application name'! !

!AbstractApplication methodsFor: 'other' stamp: 'BrunoBB 12/27/2015 12:17'!
throwExceptionNotInCache

	^AppObjectNotInCacheException signal: 'The Object is no in the cache'! !

AbstractApplicationObject subclass: #AppFieldValue
	instanceVariableNames: 'name value originalValue parentObject errorString format'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AbstractApplicationObjects'!

AppFieldValue subclass: #AppFieldBooelanValue
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AbstractApplicationObjects'!

!AppFieldBooelanValue class methodsFor: 'other' stamp: 'BrunoBB 12/22/2015 12:13'!
stType

	^Boolean! !

!AppFieldBooelanValue methodsFor: 'other' stamp: 'BrunoBB 12/22/2015 12:15'!
setValue: newValue
   "Modify the value of the instance variable 'value'."

	newValue ifNil: [^value := newValue].

	[value := Boolean fromString: newValue] on: Error do:[:err | errorString := err description.].

	^value! !

AppFieldValue subclass: #AppFieldDateValue
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AbstractApplicationObjects'!

!AppFieldDateValue class methodsFor: 'other' stamp: 'BrunoBB 12/22/2015 12:13'!
stType

	^Date! !

!AppFieldDateValue methodsFor: 'other' stamp: 'BrunoBB 12/22/2015 12:15'!
setValue: newValue
   "Modify the value of the instance variable 'value'."

	newValue ifNil: [^value := newValue].

	[value := Date fromMySqlString: newValue] on: Error do:[:err | errorString := err description.].

	^value! !

AppFieldValue subclass: #AppFieldNumberValue
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AbstractApplicationObjects'!

!AppFieldNumberValue class methodsFor: 'other' stamp: 'BrunoBB 12/22/2015 12:13'!
stType

	^Number! !

!AppFieldNumberValue methodsFor: 'other' stamp: 'BrunoBB 12/22/2015 12:16'!
setValue: newValue
   "Modify the value of the instance variable 'value'."

	newValue ifNil: [^value := newValue].

	[value := Number readFrom: newValue] on: Error do:[:err | errorString := err description.].

	^value! !

AppFieldValue subclass: #AppFieldStringValue
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AbstractApplicationObjects'!

!AppFieldStringValue class methodsFor: 'other' stamp: 'BrunoBB 12/22/2015 12:14'!
stType

	^String! !

!AppFieldStringValue methodsFor: 'other' stamp: 'BrunoBB 12/22/2015 12:16'!
setValue: newValue

   "Modify the value of the instance variable 'value'."
   value := newValue! !

AppFieldValue subclass: #AppFieldTimeStampValue
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AbstractApplicationObjects'!

!AppFieldTimeStampValue class methodsFor: 'other' stamp: 'BrunoBB 12/22/2015 12:14'!
stType

	^TimeStamp! !

!AppFieldTimeStampValue methodsFor: 'other' stamp: 'BrunoBB 12/22/2015 12:16'!
setValue: newValue
   "Modify the value of the instance variable 'value'."

	newValue ifNil: [^value := newValue].

	[value := TimeStamp fromMySqlString: newValue] on: Error do:[:err | errorString := err description.].

	^value! !

AppFieldValue subclass: #AppFieldTimeValue
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AbstractApplicationObjects'!

!AppFieldTimeValue class methodsFor: 'other' stamp: 'BrunoBB 12/22/2015 12:15'!
stType

	^Time! !

!AppFieldTimeValue methodsFor: 'other' stamp: 'BrunoBB 12/22/2015 12:16'!
setValue: newValue
   "Modify the value of the instance variable 'value'."

	newValue ifNil: [^value := newValue].

	[value := Time fromMySqlString: newValue] on: Error do:[:err | errorString := err description.].

	^value! !

!AppFieldValue class methodsFor: 'other' stamp: 'BrunoBB 12/26/2015 16:04'!
parentObject: anObject

	^super new initialize
		parentObject: anObject;
		yourself! !

!AppFieldValue class methodsFor: 'other' stamp: 'BrunoBB 12/26/2015 16:04'!
parentObject: aObject name: stringName value: stringValue

	^self parentObject: aObject name: stringName value: stringValue originalValue: stringValue! !

!AppFieldValue class methodsFor: 'other' stamp: 'BrunoBB 12/28/2015 11:37'!
parentObject: anObject name: stringName value: stringValue originalValue: originalValue

	^super new initialize
		parentObject: anObject;
		name: stringName;
		setValue: stringValue;
		originalValue: originalValue;
		yourself! !

!AppFieldValue class methodsFor: 'other' stamp: 'BrunoBB 12/26/2015 16:04'!
stType

	^self subclassResponsibility! !

!AppFieldValue methodsFor: 'Accessing' stamp: 'BrunoBB 12/26/2015 16:04'!
errorString
	^errorString! !

!AppFieldValue methodsFor: 'Updating' stamp: 'BrunoBB 12/26/2015 16:04'!
errorString: newValue
	errorString := newValue! !

!AppFieldValue methodsFor: 'Accessing' stamp: 'BrunoBB 12/26/2015 16:04'!
format
	^format! !

!AppFieldValue methodsFor: 'Updating' stamp: 'BrunoBB 12/26/2015 16:04'!
format: newValue
	format := newValue! !

!AppFieldValue methodsFor: 'Accessing' stamp: 'BrunoBB 12/26/2015 16:04'!
name
	^name! !

!AppFieldValue methodsFor: 'Updating' stamp: 'BrunoBB 12/26/2015 16:04'!
name: newValue
	name := newValue! !

!AppFieldValue methodsFor: 'Accessing' stamp: 'BrunoBB 12/26/2015 16:04'!
originalValue
	^originalValue! !

!AppFieldValue methodsFor: 'Updating' stamp: 'BrunoBB 12/26/2015 16:04'!
originalValue: newValue
	originalValue := newValue! !

!AppFieldValue methodsFor: 'Accessing' stamp: 'BrunoBB 12/26/2015 16:04'!
parentObject
	^parentObject! !

!AppFieldValue methodsFor: 'Updating' stamp: 'BrunoBB 12/26/2015 16:04'!
parentObject: newValue
	parentObject := newValue! !

!AppFieldValue methodsFor: 'other' stamp: 'BrunoBB 12/26/2015 16:04'!
setValue: newValue

	self subclassResponsibility! !

!AppFieldValue methodsFor: 'Accessing' stamp: 'BrunoBB 12/26/2015 16:04'!
value
	^value! !

!AppFieldValue methodsFor: 'Updating' stamp: 'BrunoBB 12/26/2015 16:04'!
value: newValue
	value := newValue! !

AbstractApplicationObject subclass: #ApplicationServerConfiguration
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AbstractApplicationObjects'!

ApplicationServerConfiguration class
	instanceVariableNames: 'default'!

!ApplicationServerConfiguration class methodsFor: 'Accessing' stamp: 'BrunoBB 02/03/2016 08:52'!
default

	default ifNil: [default := super new initialize].

	^default! !

!ApplicationServerConfiguration class methodsFor: 'Updating' stamp: 'BrunoBB 02/03/2016 08:51'!
default: newValue
	default := newValue! !

ApplicationServerConfiguration subclass: #GemStoneServerConfiguration
	instanceVariableNames: 'gemstoneIP loginModes'
	classVariableNames: 'Default'
	poolDictionaries: ''
	category: 'AbstractApplicationObjects'!

!GemStoneServerConfiguration methodsFor: 'other' stamp: 'BrunoBB 02/03/2016 09:15'!
bindPasswordForWebOrbeon

	^(loginModes at: 'orbeon-web') bindPassword! !

!GemStoneServerConfiguration methodsFor: 'other' stamp: 'BrunoBB 02/03/2016 09:15'!
bindPasswordForWebProcess

	^(loginModes at: 'orbeon-processes-web') bindPassword! !

!GemStoneServerConfiguration methodsFor: 'other' stamp: 'BrunoBB 02/03/2016 09:15'!
dnForWebOrbeon

	^(loginModes at: 'orbeon-web') dn! !

!GemStoneServerConfiguration methodsFor: 'other' stamp: 'BrunoBB 02/03/2016 09:15'!
dnForWebProcess

	^(loginModes at: 'orbeon-processes-web') dn! !

!GemStoneServerConfiguration methodsFor: 'Accessing' stamp: 'BrunoBB 02/02/2016 20:16'!
gemstoneIP
	^gemstoneIP! !

!GemStoneServerConfiguration methodsFor: 'Updating' stamp: 'BrunoBB 02/02/2016 20:16'!
gemstoneIP: newValue
	gemstoneIP := newValue! !

!GemStoneServerConfiguration methodsFor: 'other' stamp: 'BrunoBB 02/03/2016 09:14'!
initialize

	super initialize.

	loginModes := Dictionary new.

	"Intitally we set the user as Local not in LDAP"
	self setLocalForOrbeon.
	self setLocalForProcesses.! !

!GemStoneServerConfiguration methodsFor: 'other' stamp: 'BrunoBB 02/03/2016 09:15'!
ldapIpForWebOrbeon

	^(loginModes at: 'orbeon-web') ldapIP! !

!GemStoneServerConfiguration methodsFor: 'other' stamp: 'BrunoBB 02/03/2016 09:15'!
ldapIpForWebProcess

	^(loginModes at: 'orbeon-processes-web') ldapIP! !

!GemStoneServerConfiguration methodsFor: 'other' stamp: 'BrunoBB 02/03/2016 09:15'!
loginModeFor: webAppName

	^loginModes at: webAppName ifAbsent: [nil]! !

!GemStoneServerConfiguration methodsFor: 'Accessing' stamp: 'BrunoBB 02/02/2016 20:16'!
loginModes
	^loginModes! !

!GemStoneServerConfiguration methodsFor: 'Updating' stamp: 'BrunoBB 02/02/2016 20:16'!
loginModes: newValue
	loginModes := newValue! !

!GemStoneServerConfiguration methodsFor: 'other' stamp: 'BrunoBB 02/03/2016 09:15'!
ouForWebOrbeon

	^(loginModes at: 'orbeon-web') ou! !

!GemStoneServerConfiguration methodsFor: 'other' stamp: 'BrunoBB 02/03/2016 09:15'!
ouForWebProcess

	^(loginModes at: 'orbeon-processes-web') ou! !

ApplicationServerConfiguration subclass: #OrbeonDatabaseConfiguration
	instanceVariableNames: 'databaseIP databaseUser databasePassword'
	classVariableNames: 'Default'
	poolDictionaries: ''
	category: 'AbstractApplicationObjects'!

!OrbeonDatabaseConfiguration methodsFor: 'Accessing' stamp: 'BrunoBB 02/03/2016 08:52'!
databaseIP
	^databaseIP! !

!OrbeonDatabaseConfiguration methodsFor: 'Updating' stamp: 'BrunoBB 02/03/2016 08:52'!
databaseIP: newValue
	databaseIP := newValue! !

!OrbeonDatabaseConfiguration methodsFor: 'Accessing' stamp: 'BrunoBB 02/03/2016 08:52'!
databasePassword
	^databasePassword! !

!OrbeonDatabaseConfiguration methodsFor: 'Updating' stamp: 'BrunoBB 02/03/2016 08:52'!
databasePassword: newValue
	databasePassword := newValue! !

!OrbeonDatabaseConfiguration methodsFor: 'Accessing' stamp: 'BrunoBB 02/03/2016 08:52'!
databaseUser
	^databaseUser! !

!OrbeonDatabaseConfiguration methodsFor: 'Updating' stamp: 'BrunoBB 02/03/2016 08:52'!
databaseUser: newValue
	databaseUser := newValue! !

ApplicationServerConfiguration subclass: #OrbeonServerConfiguration
	instanceVariableNames: 'orbeonIP'
	classVariableNames: 'Default'
	poolDictionaries: ''
	category: 'AbstractApplicationObjects'!

!OrbeonServerConfiguration methodsFor: 'Accessing' stamp: 'BrunoBB 02/03/2016 10:07'!
orbeonIP
	^orbeonIP! !

!OrbeonServerConfiguration methodsFor: 'Updating' stamp: 'BrunoBB 02/03/2016 10:07'!
orbeonIP: newValue
	orbeonIP := newValue! !

AbstractApplicationObject subclass: #ApplicationUser
	instanceVariableNames: 'username password'
	classVariableNames: 'Cache'
	poolDictionaries: ''
	category: 'AbstractApplicationObjects'!

!ApplicationUser class methodsFor: 'other' stamp: 'BrunoBB 12/20/2015 11:16'!
cache

	Cache ifNil: [self initializeCache].

	^Cache! !

!ApplicationUser class methodsFor: 'other' stamp: 'BrunoBB 12/20/2015 11:37'!
getExistingOrNewUserNamed: aString

	^(self getUserNamed: aString) 
		ifNil: [(self newUserNamed: aString password: '') addToCache; yourself]
		ifNotNil: [:user | user]! !

!ApplicationUser class methodsFor: 'other' stamp: 'BrunoBB 12/20/2015 11:17'!
getUserNamed: aString

	^self cache at: aString ifAbsent: [nil]! !

!ApplicationUser class methodsFor: 'other' stamp: 'BrunoBB 12/20/2015 11:16'!
initializeCache

	Cache := Dictionary new.! !

!ApplicationUser class methodsFor: 'other' stamp: 'BrunoBB 12/20/2015 11:26'!
newUserNamed: aString password: pwd

	^super new initialize
		username: aString;
		password: pwd;
		yourself! !

!ApplicationUser methodsFor: 'other' stamp: 'BrunoBB 12/20/2015 11:18'!
addToCache

	^self class cache at: username put: self! !

!ApplicationUser methodsFor: 'Accessing' stamp: 'BrunoBB 12/20/2015 11:16'!
password
	^password! !

!ApplicationUser methodsFor: 'Updating' stamp: 'BrunoBB 12/20/2015 11:16'!
password: newValue
	password := newValue! !

!ApplicationUser methodsFor: 'Accessing' stamp: 'BrunoBB 12/20/2015 11:16'!
username
	^username! !

!ApplicationUser methodsFor: 'Updating' stamp: 'BrunoBB 12/20/2015 11:16'!
username: newValue
	username := newValue! !

!Object class methodsFor: '*abstractApplicationObjects' stamp: 'BrunoBB 02/08/2016 13:26'!
getApplicationManagerClass
	"The receiver answer the class used as applications manager"

	^AbstractApplication! !

!Object class methodsFor: '*abstractApplicationObjects' stamp: 'BrunoBB 02/03/2016 09:22'!
getGemStoneServerConfiguration

	^GemStoneServerConfiguration default! !

!Object class methodsFor: '*abstractApplicationObjects' stamp: 'BrunoBB 02/03/2016 08:53'!
getOrbeonDatabaseConfiguration

	^OrbeonDatabaseConfiguration default! !

!Object class methodsFor: '*abstractApplicationObjects' stamp: 'BrunoBB 02/03/2016 10:07'!
getOrbeonWebServerConfiguration

	^OrbeonServerConfiguration default! !

!Object methodsFor: '*abstractApplicationObjects' stamp: 'BrunoBB 02/08/2016 13:25'!
getApplicationManagerClass
	"The receiver answer the class used as applications manager"

	^self class getApplicationManagerClass! !

!Object methodsFor: '*abstractApplicationObjects' stamp: 'BrunoBB 02/03/2016 09:23'!
getGemStoneServerConfiguration

	^self class getGemStoneServerConfiguration! !

!Object methodsFor: '*abstractApplicationObjects' stamp: 'BrunoBB 02/03/2016 08:53'!
getOrbeonDatabaseConfiguration

	^self class getOrbeonDatabaseConfiguration! !

!Object methodsFor: '*abstractApplicationObjects' stamp: 'BrunoBB 02/03/2016 08:44'!
getOrbeonWebServerConfiguration

	^self class getOrbeonWebServerConfiguration! !
